import vega from 'vega';
import vegaLite from 'vega-lite';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';
import { viz } from './viz';

vl.register(vega, vegaLite, {
  view: { renderer: 'svg' },
  init: view => { view.tooltip(new Handler().call); }
});


const type = Array('Food','Water')
const selection = vl.selectSingle('Select') // name the selection 'Select'
    .fields('Primary Mode')          // limit selection to the Primary Mode field
    .init({"Primary Mode": type[0]}) // use first type entry as initial value
    .bind(vl.menu(type));  // bind to a menu of unique type values
console.log(selection)

const run = async () => {
  const marks = viz
    .data(await getData())
  	.select(selection)
    .width(window.innerWidth)
    .height(window.innerHeight-30)
    .autosize({ type: 'fit', contains: 'padding' })
    .config(config);
  
  document.body.appendChild(await marks.render());
};
run();